[jbpm-commits] JBoss JBPM SVN: r1562 - in api/trunk: modules/testsuite/src/test/java/org/jboss/bpm/samples/engine and 3 other directories.

do-not-reply at jboss.org do-not-reply at jboss.org
Wed Jul 9 15:14:53 EDT 2008


Author: thomas.diesler at jboss.com
Date: 2008-07-09 15:14:53 -0400 (Wed, 09 Jul 2008)
New Revision: 1562

Added:
   api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn
   api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn_diagram
   api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.png
   api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn
   api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn_diagram
   api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.png
Modified:
   api/trunk/.project
   api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/engine/EngineShutdownTest.java
   api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/task/BasicTaskTest.java
Log:
Add BPMN resources

Modified: api/trunk/.project
===================================================================
--- api/trunk/.project	2008-07-09 18:27:25 UTC (rev 1561)
+++ api/trunk/.project	2008-07-09 19:14:53 UTC (rev 1562)
@@ -15,9 +15,15 @@
 			<arguments>
 			</arguments>
 		</buildCommand>
+		<buildCommand>
+			<name>org.eclipse.stp.bpmn.validation.BatchValidationBuilder</name>
+			<arguments>
+			</arguments>
+		</buildCommand>
 	</buildSpec>
 	<natures>
 		<nature>org.eclipse.jdt.core.javanature</nature>
 		<nature>org.maven.ide.eclipse.maven2Nature</nature>
+		<nature>org.eclipse.stp.bpmn.validation.BatchValidationBuildAbleNature</nature>
 	</natures>
 </projectDescription>

Modified: api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/engine/EngineShutdownTest.java
===================================================================
--- api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/engine/EngineShutdownTest.java	2008-07-09 18:27:25 UTC (rev 1561)
+++ api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/engine/EngineShutdownTest.java	2008-07-09 19:14:53 UTC (rev 1562)
@@ -53,9 +53,9 @@
   }
 
   /**
-   * Try to create a ProcessDefinition during shutdown
+   * Try to create a Process during shutdown
    */
-  public void testCreateProcessDefinition() throws Exception 
+  public void testCreateProcess() throws Exception 
   {
     // Create a Process through the ProcessManager
     ProcessManager pm = ProcessManager.locateProcessManager();

Modified: api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/task/BasicTaskTest.java
===================================================================
--- api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn	                        (rev 0)
+++ api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn	2008-07-09 19:14:53 UTC (rev 1562)
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<bpmn:BpmnDiagram xmi:version="2.0" xmlns:xmi="http://www.omg.org/XMI" xmlns:bpmn="http://stp.eclipse.org/bpmn" xmi:id="_UstEIE3nEd2LNJlZf0NQOw" iD="_UspZwE3nEd2LNJlZf0NQOw">
+  <pools xmi:type="bpmn:Pool" xmi:id="_Ut2ToE3nEd2LNJlZf0NQOw" iD="_Ut1skE3nEd2LNJlZf0NQOw" name="Pool">
+    <vertices xmi:type="bpmn:Activity" xmi:id="_UuUNsU3nEd2LNJlZf0NQOw" iD="_UuUNsE3nEd2LNJlZf0NQOw" outgoingEdges="_c8S7wU3nEd2LNJlZf0NQOw" incomingEdges="_bWie4E3nEd2LNJlZf0NQOw" name="StateA" activityType="Task"/>
+    <vertices xmi:type="bpmn:Activity" xmi:id="_aeNvwE3nEd2LNJlZf0NQOw" iD="_aeNIsE3nEd2LNJlZf0NQOw" outgoingEdges="_bWie4E3nEd2LNJlZf0NQOw" activityType="EventStartEmpty"/>
+    <vertices xmi:type="bpmn:Activity" xmi:id="_cUlbgU3nEd2LNJlZf0NQOw" iD="_cUlbgE3nEd2LNJlZf0NQOw" incomingEdges="_c8S7wU3nEd2LNJlZf0NQOw" activityType="EventEndEmpty"/>
+    <sequenceEdges xmi:type="bpmn:SequenceEdge" xmi:id="_bWie4E3nEd2LNJlZf0NQOw" iD="_bWh30E3nEd2LNJlZf0NQOw" source="_aeNvwE3nEd2LNJlZf0NQOw" target="_UuUNsU3nEd2LNJlZf0NQOw"/>
+    <sequenceEdges xmi:type="bpmn:SequenceEdge" xmi:id="_c8S7wU3nEd2LNJlZf0NQOw" iD="_c8S7wE3nEd2LNJlZf0NQOw" source="_UuUNsU3nEd2LNJlZf0NQOw" target="_cUlbgU3nEd2LNJlZf0NQOw"/>
+  </pools>
+</bpmn:BpmnDiagram>

Added: api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn_diagram
===================================================================
--- api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn_diagram	                        (rev 0)
+++ api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn_diagram	2008-07-09 19:14:53 UTC (rev 1562)
@@ -0,0 +1,72 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<notation:Diagram xmi:version="2.0" xmlns:xmi="http://www.omg.org/XMI" xmlns:bpmn="http://stp.eclipse.org/bpmn" xmlns:notation="http://www.eclipse.org/gmf/runtime/1.0.1/notation" xmi:id="_UtiKkE3nEd2LNJlZf0NQOw" type="Bpmn" name="basic-sequence.bpmn_diagram" measurementUnit="Pixel">
+  <children xmi:type="notation:Node" xmi:id="_Uufz4E3nEd2LNJlZf0NQOw" type="1001">
+    <children xmi:type="notation:Node" xmi:id="_UuksYE3nEd2LNJlZf0NQOw" type="4008"/>
+    <children xmi:type="notation:Node" xmi:id="_UunIoE3nEd2LNJlZf0NQOw" type="5001">
+      <children xmi:type="notation:Node" xmi:id="_Uupk4E3nEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_UuqL8E3nEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_Uupk4U3nEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_Uupk4k3nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_Uupk403nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_Uupk5E3nEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-sequence.bpmn#_UuUNsU3nEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_UuqL8U3nEd2LNJlZf0NQOw" x="84" y="28" width="111" height="61"/>
+      </children>
+      <children xmi:type="notation:Node" xmi:id="_aeUdcE3nEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_aeW5sE3nEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_aeVEgE3nEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_aeVEgU3nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_aeVEgk3nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_aeVEg03nEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-sequence.bpmn#_aeNvwE3nEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_aeVEhE3nEd2LNJlZf0NQOw" x="12" y="40"/>
+      </children>
+      <children xmi:type="notation:Node" xmi:id="_cUmpoE3nEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_cUnQsE3nEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_cUmpoU3nEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_cUmpok3nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_cUmpo03nEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_cUmppE3nEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-sequence.bpmn#_cUlbgU3nEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_cUmppU3nEd2LNJlZf0NQOw" x="240" y="40"/>
+      </children>
+      <styles xmi:type="notation:DrawerStyle" xmi:id="_UunvsE3nEd2LNJlZf0NQOw"/>
+      <styles xmi:type="notation:SortingStyle" xmi:id="_UunvsU3nEd2LNJlZf0NQOw"/>
+      <styles xmi:type="notation:FilteringStyle" xmi:id="_Uunvsk3nEd2LNJlZf0NQOw"/>
+    </children>
+    <styles xmi:type="notation:FontStyle" xmi:id="_Uufz4U3nEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:DescriptionStyle" xmi:id="_Uufz4k3nEd2LNJlZf0NQOw"/>
+    <styles xmi:type="notation:FillStyle" xmi:id="_Uufz403nEd2LNJlZf0NQOw" fillColor="16771304"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_Uufz5E3nEd2LNJlZf0NQOw" lineColor="11119017"/>
+    <element xmi:type="bpmn:Pool" href="basic-sequence.bpmn#_Ut2ToE3nEd2LNJlZf0NQOw"/>
+    <layoutConstraint xmi:type="notation:Bounds" xmi:id="_Uunvs03nEd2LNJlZf0NQOw" x="16" y="16" width="333" height="129"/>
+  </children>
+  <styles xmi:type="notation:PageStyle" xmi:id="_UtiKkU3nEd2LNJlZf0NQOw"/>
+  <styles xmi:type="notation:GuideStyle" xmi:id="_UtiKkk3nEd2LNJlZf0NQOw"/>
+  <styles xmi:type="notation:DescriptionStyle" xmi:id="_UtiKk03nEd2LNJlZf0NQOw"/>
+  <element xmi:type="bpmn:BpmnDiagram" href="basic-sequence.bpmn#_UstEIE3nEd2LNJlZf0NQOw"/>
+  <edges xmi:type="notation:Edge" xmi:id="_bWolgE3nEd2LNJlZf0NQOw" type="3001" source="_aeUdcE3nEd2LNJlZf0NQOw" target="_Uupk4E3nEd2LNJlZf0NQOw">
+    <children xmi:type="notation:Node" xmi:id="_bWqasE3nEd2LNJlZf0NQOw" type="4012">
+      <styles xmi:type="notation:FillStyle" xmi:id="_bWqasU3nEd2LNJlZf0NQOw" fillColor="16776959"/>
+      <styles xmi:type="notation:LineStyle" xmi:id="_bWqask3nEd2LNJlZf0NQOw" lineColor="16776959"/>
+      <layoutConstraint xmi:type="notation:Location" xmi:id="_bWqas03nEd2LNJlZf0NQOw" y="-10"/>
+    </children>
+    <styles xmi:type="notation:RoutingStyle" xmi:id="_bWolgU3nEd2LNJlZf0NQOw" routing="Rectilinear" smoothness="Normal" closestDistance="true"/>
+    <styles xmi:type="notation:FontStyle" xmi:id="_bWolgk3nEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_bWolg03nEd2LNJlZf0NQOw" lineColor="0"/>
+    <element xmi:type="bpmn:SequenceEdge" href="basic-sequence.bpmn#_bWie4E3nEd2LNJlZf0NQOw"/>
+    <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_bWolhE3nEd2LNJlZf0NQOw" points="[0, -15, -110, -16]$[57, -2, -53, -3]"/>
+  </edges>
+  <edges xmi:type="notation:Edge" xmi:id="_c8Uw8E3nEd2LNJlZf0NQOw" type="3001" source="_Uupk4E3nEd2LNJlZf0NQOw" target="_cUmpoE3nEd2LNJlZf0NQOw">
+    <children xmi:type="notation:Node" xmi:id="_c8VYAE3nEd2LNJlZf0NQOw" type="4012">
+      <styles xmi:type="notation:FillStyle" xmi:id="_c8VYAU3nEd2LNJlZf0NQOw" fillColor="16776959"/>
+      <styles xmi:type="notation:LineStyle" xmi:id="_c8VYAk3nEd2LNJlZf0NQOw" lineColor="16776959"/>
+      <layoutConstraint xmi:type="notation:Location" xmi:id="_c8VYA03nEd2LNJlZf0NQOw" y="-10"/>
+    </children>
+    <styles xmi:type="notation:RoutingStyle" xmi:id="_c8Uw8U3nEd2LNJlZf0NQOw" routing="Rectilinear" smoothness="Normal" closestDistance="true"/>
+    <styles xmi:type="notation:FontStyle" xmi:id="_c8Uw8k3nEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_c8Uw803nEd2LNJlZf0NQOw" lineColor="0"/>
+    <element xmi:type="bpmn:SequenceEdge" href="basic-sequence.bpmn#_c8S7wU3nEd2LNJlZf0NQOw"/>
+    <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_c8Uw9E3nEd2LNJlZf0NQOw" points="[54, -8, -64, -7]$[103, -2, -15, -1]"/>
+  </edges>
+</notation:Diagram>

Added: api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.png
===================================================================
(Binary files differ)


Property changes on: api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn
===================================================================
--- api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn	                        (rev 0)
+++ api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn	2008-07-09 19:14:53 UTC (rev 1562)
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<bpmn:BpmnDiagram xmi:version="2.0" xmlns:xmi="http://www.omg.org/XMI" xmlns:bpmn="http://stp.eclipse.org/bpmn" xmi:id="_v3HKgE3oEd2LNJlZf0NQOw" iD="_v3GjcE3oEd2LNJlZf0NQOw">
+  <pools xmi:type="bpmn:Pool" xmi:id="_v3IYoE3oEd2LNJlZf0NQOw" iD="_v3HKhU3oEd2LNJlZf0NQOw" name="Pool">
+    <vertices xmi:type="bpmn:Activity" xmi:id="_v3IYok3oEd2LNJlZf0NQOw" iD="_v3IYoU3oEd2LNJlZf0NQOw" outgoingEdges="_z-pnoU3oEd2LNJlZf0NQOw" incomingEdges="_yiytoU3oEd2LNJlZf0NQOw" name="TaskA" activityType="Task"/>
+    <vertices xmi:type="bpmn:Activity" xmi:id="_x8eUgU3oEd2LNJlZf0NQOw" iD="_x8eUgE3oEd2LNJlZf0NQOw" outgoingEdges="_yiytoU3oEd2LNJlZf0NQOw" activityType="EventStartEmpty"/>
+    <vertices xmi:type="bpmn:Activity" xmi:id="_zOy4AU3oEd2LNJlZf0NQOw" iD="_zOy4AE3oEd2LNJlZf0NQOw" incomingEdges="_z-pnoU3oEd2LNJlZf0NQOw" activityType="EventEndEmpty"/>
+    <sequenceEdges xmi:type="bpmn:SequenceEdge" xmi:id="_yiytoU3oEd2LNJlZf0NQOw" iD="_yiytoE3oEd2LNJlZf0NQOw" source="_x8eUgU3oEd2LNJlZf0NQOw" target="_v3IYok3oEd2LNJlZf0NQOw"/>
+    <sequenceEdges xmi:type="bpmn:SequenceEdge" xmi:id="_z-pnoU3oEd2LNJlZf0NQOw" iD="_z-pnoE3oEd2LNJlZf0NQOw" source="_v3IYok3oEd2LNJlZf0NQOw" target="_zOy4AU3oEd2LNJlZf0NQOw"/>
+  </pools>
+</bpmn:BpmnDiagram>

Added: api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn_diagram
===================================================================
--- api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn_diagram	                        (rev 0)
+++ api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.bpmn_diagram	2008-07-09 19:14:53 UTC (rev 1562)
@@ -0,0 +1,72 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<notation:Diagram xmi:version="2.0" xmlns:xmi="http://www.omg.org/XMI" xmlns:bpmn="http://stp.eclipse.org/bpmn" xmlns:notation="http://www.eclipse.org/gmf/runtime/1.0.1/notation" xmi:id="_v3HKgU3oEd2LNJlZf0NQOw" type="Bpmn" name="basic-task.bpmn_diagram" measurementUnit="Pixel">
+  <children xmi:type="notation:Node" xmi:id="_v3I_sE3oEd2LNJlZf0NQOw" type="1001">
+    <children xmi:type="notation:Node" xmi:id="_v3I_tk3oEd2LNJlZf0NQOw" type="4008"/>
+    <children xmi:type="notation:Node" xmi:id="_v3I_t03oEd2LNJlZf0NQOw" type="5001">
+      <children xmi:type="notation:Node" xmi:id="_v3JmwE3oEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_v3Jmxk3oEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_v3JmwU3oEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_v3Jmwk3oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_v3Jmw03oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_v3JmxE3oEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-task.bpmn#_v3IYok3oEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_v3Jmx03oEd2LNJlZf0NQOw" x="84" y="36" width="111" height="61"/>
+      </children>
+      <children xmi:type="notation:Node" xmi:id="_x8fioE3oEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_x8gwwE3oEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_x8fioU3oEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_x8fiok3oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_x8fio03oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_x8fipE3oEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-task.bpmn#_x8eUgU3oEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_x8fipU3oEd2LNJlZf0NQOw" x="10" y="47"/>
+      </children>
+      <children xmi:type="notation:Node" xmi:id="_zO0GIE3oEd2LNJlZf0NQOw" type="2001">
+        <children xmi:type="notation:Node" xmi:id="_zO0tME3oEd2LNJlZf0NQOw" type="4001"/>
+        <styles xmi:type="notation:FontStyle" xmi:id="_zO0GIU3oEd2LNJlZf0NQOw" fontName="Arial"/>
+        <styles xmi:type="notation:DescriptionStyle" xmi:id="_zO0GIk3oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:FillStyle" xmi:id="_zO0GI03oEd2LNJlZf0NQOw"/>
+        <styles xmi:type="notation:LineStyle" xmi:id="_zO0GJE3oEd2LNJlZf0NQOw" lineColor="0"/>
+        <element xmi:type="bpmn:Activity" href="basic-task.bpmn#_zOy4AU3oEd2LNJlZf0NQOw"/>
+        <layoutConstraint xmi:type="notation:Bounds" xmi:id="_zO0GJU3oEd2LNJlZf0NQOw" x="240" y="48"/>
+      </children>
+      <styles xmi:type="notation:DrawerStyle" xmi:id="_v3I_uE3oEd2LNJlZf0NQOw"/>
+      <styles xmi:type="notation:SortingStyle" xmi:id="_v3I_uU3oEd2LNJlZf0NQOw"/>
+      <styles xmi:type="notation:FilteringStyle" xmi:id="_v3I_uk3oEd2LNJlZf0NQOw"/>
+    </children>
+    <styles xmi:type="notation:FontStyle" xmi:id="_v3I_sU3oEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:DescriptionStyle" xmi:id="_v3I_sk3oEd2LNJlZf0NQOw"/>
+    <styles xmi:type="notation:FillStyle" xmi:id="_v3I_s03oEd2LNJlZf0NQOw" fillColor="16771304"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_v3I_tE3oEd2LNJlZf0NQOw" lineColor="11119017"/>
+    <element xmi:type="bpmn:Pool" href="basic-task.bpmn#_v3IYoE3oEd2LNJlZf0NQOw"/>
+    <layoutConstraint xmi:type="notation:Bounds" xmi:id="_v3I_u03oEd2LNJlZf0NQOw" x="16" y="16" width="345" height="141"/>
+  </children>
+  <styles xmi:type="notation:PageStyle" xmi:id="_v3HKgk3oEd2LNJlZf0NQOw"/>
+  <styles xmi:type="notation:GuideStyle" xmi:id="_v3HKg03oEd2LNJlZf0NQOw"/>
+  <styles xmi:type="notation:DescriptionStyle" xmi:id="_v3HKhE3oEd2LNJlZf0NQOw"/>
+  <element xmi:type="bpmn:BpmnDiagram" href="basic-task.bpmn#_v3HKgE3oEd2LNJlZf0NQOw"/>
+  <edges xmi:type="notation:Edge" xmi:id="_yiz7wE3oEd2LNJlZf0NQOw" type="3001" source="_x8fioE3oEd2LNJlZf0NQOw" target="_v3JmwE3oEd2LNJlZf0NQOw">
+    <children xmi:type="notation:Node" xmi:id="_yi0i0E3oEd2LNJlZf0NQOw" type="4012">
+      <styles xmi:type="notation:FillStyle" xmi:id="_yi0i0U3oEd2LNJlZf0NQOw" fillColor="16776959"/>
+      <styles xmi:type="notation:LineStyle" xmi:id="_yi0i0k3oEd2LNJlZf0NQOw" lineColor="16776959"/>
+      <layoutConstraint xmi:type="notation:Location" xmi:id="_yi0i003oEd2LNJlZf0NQOw" y="-10"/>
+    </children>
+    <styles xmi:type="notation:RoutingStyle" xmi:id="_yiz7wU3oEd2LNJlZf0NQOw" routing="Rectilinear" smoothness="Normal" closestDistance="true"/>
+    <styles xmi:type="notation:FontStyle" xmi:id="_yiz7wk3oEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_yiz7w03oEd2LNJlZf0NQOw" lineColor="0"/>
+    <element xmi:type="bpmn:SequenceEdge" href="basic-task.bpmn#_yiytoU3oEd2LNJlZf0NQOw"/>
+    <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_yiz7xE3oEd2LNJlZf0NQOw" points="[15, -2, -97, -4]$[59, 0, -53, -2]"/>
+  </edges>
+  <edges xmi:type="notation:Edge" xmi:id="_z-q1wE3oEd2LNJlZf0NQOw" type="3001" source="_v3JmwE3oEd2LNJlZf0NQOw" target="_zO0GIE3oEd2LNJlZf0NQOw">
+    <children xmi:type="notation:Node" xmi:id="_z-sD4E3oEd2LNJlZf0NQOw" type="4012">
+      <styles xmi:type="notation:FillStyle" xmi:id="_z-sD4U3oEd2LNJlZf0NQOw" fillColor="16776959"/>
+      <styles xmi:type="notation:LineStyle" xmi:id="_z-sD4k3oEd2LNJlZf0NQOw" lineColor="16776959"/>
+      <layoutConstraint xmi:type="notation:Location" xmi:id="_z-sD403oEd2LNJlZf0NQOw" y="-10"/>
+    </children>
+    <styles xmi:type="notation:RoutingStyle" xmi:id="_z-rc0E3oEd2LNJlZf0NQOw" routing="Rectilinear" smoothness="Normal" closestDistance="true"/>
+    <styles xmi:type="notation:FontStyle" xmi:id="_z-rc0U3oEd2LNJlZf0NQOw" fontName="Arial"/>
+    <styles xmi:type="notation:LineStyle" xmi:id="_z-rc0k3oEd2LNJlZf0NQOw" lineColor="0"/>
+    <element xmi:type="bpmn:SequenceEdge" href="basic-task.bpmn#_z-pnoU3oEd2LNJlZf0NQOw"/>
+    <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_z-rc003oEd2LNJlZf0NQOw" points="[-53, -22, -171, -21]$[103, -2, -15, -1]"/>
+  </edges>
+</notation:Diagram>

Added: api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.png
===================================================================
(Binary files differ)


Property changes on: api/trunk/modules/testsuite/src/test/resources/samples/task/basic-task.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream




More information about the jbpm-commits mailing list
--- api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/task/BasicTaskTest.java	2008-07-09 18:27:25 UTC (rev 1561)
+++ api/trunk/modules/testsuite/src/test/java/org/jboss/bpm/samples/task/BasicTaskTest.java	2008-07-09 19:14:53 UTC (rev 1562)
@@ -55,10 +55,10 @@
   }
 
   /**
    * Test that the execution context variables set by the Activity
    * are visible to the client. 
    */
-  public void testBasicActivity() throws Exception
+  public void testBasicTask() throws Exception
   {
     // Create a Process through the ProcessManager
     ProcessManager pm = ProcessManager.locateProcessManager();
@@ -55,10 +55,10 @@
 
   /**
-   * Test that the execution context variables set by the Activity
+   * Test that the execution context variables set by the Task
    * are visible to the client. 
    */

Added: api/trunk/modules/testsuite/src/test/resources/samples/sequence/basic-sequence.bpmn
===================================================================